==> prestashop_1.4.0.7.zip: prestashop/modules/fedexcarrier/es.php <==
<?php

global $_MODULE;
$_MODULE = array();
$_MODULE['<{fedexcarrier}prestashop>fedexcarrier_c0d00fcb670ada42dad4698b865f40cd'] = 'Transportista Fedex';
$_MODULE['<{fedexcarrier}prestashop>fedexcarrier_6aed16278d24c6e5b8cb32fb75b115a0'] = 'Proponer  sus clientes el transportista Fedex';
$_MODULE['<{fedexcarrier}prestashop>fedexcarrier_eb913e534166c405b955e203e278445c'] = ' “Cuenta Fedex”';
$_MODULE['<{fedexcarrier}prestashop>fedexcarrier_5e21aea90b6d79e7a88edf475caa19f8'] = 'Login “Fedex meter Lumber”';
$_MODULE['<{fedexcarrier}prestashop>fedexcarrier_1dd66a25c3d430c4b81fb5d0e9c96a87'] = ' “Contraseña Fedex”';
$_MODULE['<{fedexcarrier}prestashop>fedexcarrier_81afdae0b8a0186f748de1395139f13d'] = ' “Fedex API Key”';
$_MODULE['<{fedexcarrier}prestashop>fedexcarrier_76abc208d2df4a91e55997c1dce3a256'] = 'Tipo de entrega por defecto';
$_MODULE['<{fedexcarrier}prestashop>fedexcarrier_3a8facb8e638e72950a3c6645c1e0deb'] = 'Código postal de la tienda (en el menú Preferencias)';
$_MODULE['<{fedexcarrier}prestashop>fedexcarrier_f65fbab1ca04b5b3ff07a995c7c7f85b'] = 'País de la tienda (en el menú Preferencias)';
$_MODULE['<{fedexcarrier}prestashop>fedexcarrier_21f60d9ad83a6212384c830829c6d73f'] = ' “Class Soap”';
$_MODULE['<{fedexcarrier}prestashop>fedexcarrier_6b6b893e432711e4188b7fa40dca078f'] = 'La unidad de medida de peso debe ser LB o KG (en el menú Preferencias>Ubicación)';
$_MODULE['<{fedexcarrier}prestashop>fedexcarrier_2a7203ece638dc235eeaef9927c52c4b'] = 'La unidad de medida de dimensión debe ser CM o IN (en el menú Preferencias>Ubicación)';
$_MODULE['<{fedexcarrier}prestashop>fedexcarrier_4d470fde8487e755a50e9235e3dc13ab'] = 'deben configurarse correctamente para poder utilizar este módulo';
$_MODULE['<{fedexcarrier}prestashop>fedexcarrier_5bb8a37c6acccadf3e28a704d59f1f8a'] = 'Business service center';
$_MODULE['<{fedexcarrier}prestashop>fedexcarrier_b5a7adde1af5c87d7fd797b6245c2a39'] = 'Descripción';
$_MODULE['<{fedexcarrier}prestashop>fedexcarrier_c076e1515534794deeaec631560ae598'] = 'Configuración del transportista Fedex';
$_MODULE['<{fedexcarrier}prestashop>fedexcarrier_685abc1e0806b2e9b2a801cd9929b91a'] = 'En esta versión el módulo Fedex va a elegir automáticamente el servicio de entrega disponible más económico.';
$_MODULE['<{fedexcarrier}prestashop>fedexcarrier_52f4393e1b52ba63e27310ca92ba098c'] = 'Configuración general';
$_MODULE['<{fedexcarrier}prestashop>fedexcarrier_a50bb127f9b307757cf52ab86d70adac'] = 'Su cuenta Fedex';
$_MODULE['<{fedexcarrier}prestashop>fedexcarrier_9a8b0ebd10992bd1576eccf605a84175'] = 'Su Fedex Mater Lumber';
$_MODULE['<{fedexcarrier}prestashop>fedexcarrier_c36a272a8778a2e85de52a01675fd521'] = 'Su contraseña fedex';
$_MODULE['<{fedexcarrier}prestashop>fedexcarrier_5e2cd475470bc7b47bef8d4ecdae2a67'] = 'Su Fedex Key API';
$_MODULE['<{fedexcarrier}prestashop>fedexcarrier_cdfa1b01c330bf745f776f6c6c8afffd'] = 'Pulse aquí para obtener su Fedex Key API';
$_MODULE['<{fedexcarrier}prestashop>fedexcarrier_f405714368454e1f9c932432693aea42'] = 'Tipo de entrega por defecto';
$_MODULE['<{fedexcarrier}prestashop>fedexcarrier_ce135482b30deedcc0046df41c12de79'] = 'Elija su método de entrega por defecto…';
$_MODULE['<{fedexcarrier}prestashop>fedexcarrier_bc064abb5f05b78fc963c15ac918d817'] = 'Elija su método de entrega por defecto';
$_MODULE['<{fedexcarrier}prestashop>fedexcarrier_a43dd1733f4aa62a88a6e9e0a0dcb90a'] = 'No se ha especificado el método de entrega por defecto';
$_MODULE['<{fedexcarrier}prestashop>fedexcarrier_df7889253ebbfdfb2c75bbdad08bab77'] = 'No se ha especificado el código postal de la tienda (menú Preferencias)';
$_MODULE['<{fedexcarrier}prestashop>fedexcarrier_402c9e33527dff0fb96c444b066614d0'] = 'No se ha especificado el país de la tienda (menú Preferencias)';
$_MODULE['<{fedexcarrier}prestashop>fedexcarrier_f57f4a0f8468f6c27c7108f7e584b6cb'] = 'La unidad de medida del peso debe ser LB o KG (en el menú Preferencias>Ubicación)';
$_MODULE['<{fedexcarrier}prestashop>fedexcarrier_ce0c761d1e40a0da7349462787c91ac7'] = 'La unidad de medida de las dimensiones debe ser CM o IN (en el menú Preferencias>Ubicación';
$_MODULE['<{fedexcarrier}prestashop>fedexcarrier_9b8c4a7116e8c44e4ebc955fafd47586'] = 'No se ha especificado su cuenta Fedex';
$_MODULE['<{fedexcarrier}prestashop>fedexcarrier_b9cc1a101547b3ece6d946dbbe3469d7'] = 'No se ha especificado su Fedex meter Lumber';
$_MODULE['<{fedexcarrier}prestashop>fedexcarrier_5ce0f66588bbbbbb3ef0634e5ea7da69'] = 'No se ha especificado su contraseña Fedex';
$_MODULE['<{fedexcarrier}prestashop>fedexcarrier_7988c0adb770f0f945814c0fb2b5800b'] = 'No se ha especificado su Fedex API Key';
$_MODULE['<{fedexcarrier}prestashop>fedexcarrier_5d5ae09e7b6041d3449ef2cbfc39f560'] = 'No se ha especificado su método de entrega';
$_MODULE['<{fedexcarrier}prestashop>fedexcarrier_74fbfada3ebaeb00a8d14cd2c8857ec0'] = 'PrestaShop no ha podido conectarse a los servicios web de Fedex, compruebe su clave API';
$_MODULE['<{fedexcarrier}prestashop>fedexcarrier_fd0119c2a5fc18aa64887b5b7ab41c19'] = 'Se ha producido un error, inténtelo más tarde.';
$_MODULE['<{fedexcarrier}prestashop>fedexcarrier_c888438d14855d7d96a2724ee9c306bd'] = 'Configuración actualizada';
$_MODULE['<{fedexcarrier}prestashop>fedexcarrier_b9284bff13acffdd879ef4ac7fca5234'] = 'Configuración no actualizada';

==> prestashop_1.4.0.9.zip: prestashop/modules/fedexcarrier/es.php <==
<?php

global $_MODULE;
$_MODULE = array();
$_MODULE['<{fedexcarrier}prestashop>fedexcarrier_c0d00fcb670ada42dad4698b865f40cd'] = 'Transportista Fedex';
$_MODULE['<{fedexcarrier}prestashop>fedexcarrier_6aed16278d24c6e5b8cb32fb75b115a0'] = 'Proponer  sus clientes el transportista Fedex';
$_MODULE['<{fedexcarrier}prestashop>fedexcarrier_eb913e534166c405b955e203e278445c'] = ' “Cuenta Fedex”';
$_MODULE['<{fedexcarrier}prestashop>fedexcarrier_5e21aea90b6d79e7a88edf475caa19f8'] = 'Login “Fedex meter Lumber”';
$_MODULE['<{fedexcarrier}prestashop>fedexcarrier_1dd66a25c3d430c4b81fb5d0e9c96a87'] = ' “Contraseña Fedex”';
$_MODULE['<{fedexcarrier}prestashop>fedexcarrier_81afdae0b8a0186f748de1395139f13d'] = ' “Fedex API Key”';
$_MODULE['<{fedexcarrier}prestashop>fedexcarrier_76abc208d2df4a91e55997c1dce3a256'] = 'Tipo de entrega por defecto';
$_MODULE['<{fedexcarrier}prestashop>fedexcarrier_3a8facb8e638e72950a3c6645c1e0deb'] = 'Código postal de la tienda (en el menú Preferencias)';
$_MODULE['<{fedexcarrier}prestashop>fedexcarrier_f65fbab1ca04b5b3ff07a995c7c7f85b'] = 'País de la tienda (en el menú Preferencias)';
$_MODULE['<{fedexcarrier}prestashop>fedexcarrier_21f60d9ad83a6212384c830829c6d73f'] = ' “Class Soap”';
$_MODULE['<{fedexcarrier}prestashop>fedexcarrier_6b6b893e432711e4188b7fa40dca078f'] = 'La unidad de medida de peso debe ser LB o KG (en el menú Preferencias>Ubicación)';
$_MODULE['<{fedexcarrier}prestashop>fedexcarrier_2a7203ece638dc235eeaef9927c52c4b'] = 'La unidad de medida de dimensión debe ser CM o IN (en el menú Preferencias>Ubicación)';
$_MODULE['<{fedexcarrier}prestashop>fedexcarrier_4d470fde8487e755a50e9235e3dc13ab'] = 'deben configurarse correctamente para poder utilizar este módulo';
$_MODULE['<{fedexcarrier}prestashop>fedexcarrier_5bb8a37c6acccadf3e28a704d59f1f8a'] = 'Business service center';
$_MODULE['<{fedexcarrier}prestashop>fedexcarrier_c0b3132d2759b40e8525f2466c477d1c'] = 'Buzón de depósito';
$_MODULE['<{fedexcarrier}prestashop>fedexcarrier_22db7528d7c5df8e310bf19af75e61d3'] = 'Recogida regular';
$_MODULE['<{fedexcarrier}prestashop>fedexcarrier_7e8eb99ef29d93f494ebdc27b59444f5'] = 'Solicitud de mensajería';
$_MODULE['<{fedexcarrier}prestashop>fedexcarrier_394a844cc3d6d99eb45b4e71afde2c99'] = 'Estación';
$_MODULE['<{fedexcarrier}prestashop>fedexcarrier_46f58e2a308b68cae9d5f5dd8a5d4ad6'] = 'Europe first international priority';
$_MODULE['<{fedexcarrier}prestashop>fedexcarrier_0fd6265588d27073ef45ed36d5c00c75'] = 'Fedex 1 día flete';
$_MODULE['<{fedexcarrier}prestashop>fedexcarrier_dfa184d2bf6a5d6ee8ffebfbaa25394c'] = 'Fedex 2 días';
$_MODULE['<{fedexcarrier}prestashop>fedexcarrier_2c0f88b63bfbe05955db90f1dcccab2e'] = 'Fedex 2 días flete';
$_MODULE['<{fedexcarrier}prestashop>fedexcarrier_03aac4b90886eabd480cee819e24d09e'] = 'Fedex 3 días flete';
$_MODULE['<{fedexcarrier}prestashop>fedexcarrier_687009f2bc600c25a005b26f4cb4ab02'] = 'Fedex express saver';
$_MODULE['<{fedexcarrier}prestashop>fedexcarrier_6e8cf654ec68d7391f5d673331e2c212'] = 'Fedex flete';
$_MODULE['<{fedexcarrier}prestashop>fedexcarrier_1497c5bee4dd896e0b84c442be1e8760'] = 'Fedex ground';
$_MODULE['<{fedexcarrier}prestashop>fedexcarrier_23044a6996eda8ad80874f5bdd72a0bc'] = 'Fedex flete nacional';
$_MODULE['<{fedexcarrier}prestashop>fedexcarrier_b5a7adde1af5c87d7fd797b6245c2a39'] = 'Descripción';
$_MODULE['<{fedexcarrier}prestashop>fedexcarrier_c076e1515534794deeaec631560ae598'] = 'Configuración del transportista Fedex';
$_MODULE['<{fedexcarrier}prestashop>fedexcarrier_685abc1e0806b2e9b2a801cd9929b91a'] = 'En esta versión el módulo Fedex va a elegir automáticamente el servicio de entrega disponible más económico.';
$_MODULE['<{fedexcarrier}prestashop>fedexcarrier_52f4393e1b52ba63e27310ca92ba098c'] = 'Configuración general';
$_MODULE['<{fedexcarrier}prestashop>fedexcarrier_a50bb127f9b307757cf52ab86d70adac'] = 'Su cuenta Fedex';
$_MODULE['<{fedexcarrier}prestashop>fedexcarrier_9a8b0ebd10992bd1576eccf605a84175'] = 'Su Fedex Mater Lumber';
$_MODULE['<{fedexcarrier}prestashop>fedexcarrier_c36a272a8778a2e85de52a01675fd521'] = 'Su contraseña fedex';
$_MODULE['<{fedexcarrier}prestashop>fedexcarrier_5e2cd475470bc7b47bef8d4ecdae2a67'] = 'Su Fedex Key API';
$_MODULE['<{fedexcarrier}prestashop>fedexcarrier_cdfa1b01c330bf745f776f6c6c8afffd'] = 'Pulse aquí para obtener su Fedex Key API';
$_MODULE['<{fedexcarrier}prestashop>fedexcarrier_f405714368454e1f9c932432693aea42'] = 'Tipo de entrega por defecto';
$_MODULE['<{fedexcarrier}prestashop>fedexcarrier_ce135482b30deedcc0046df41c12de79'] = 'Elija su método de entrega por defecto…';
$_MODULE['<{fedexcarrier}prestashop>fedexcarrier_bc064abb5f05b78fc963c15ac918d817'] = 'Elija su método de entrega por defecto';
$_MODULE['<{fedexcarrier}prestashop>fedexcarrier_a43dd1733f4aa62a88a6e9e0a0dcb90a'] = 'No se ha especificado el método de entrega por defecto';
$_MODULE['<{fedexcarrier}prestashop>fedexcarrier_df7889253ebbfdfb2c75bbdad08bab77'] = 'No se ha especificado el código postal de la tienda (menú Preferencias)';
$_MODULE['<{fedexcarrier}prestashop>fedexcarrier_402c9e33527dff0fb96c444b066614d0'] = 'No se ha especificado el país de la tienda (menú Preferencias)';
$_MODULE['<{fedexcarrier}prestashop>fedexcarrier_f57f4a0f8468f6c27c7108f7e584b6cb'] = 'La unidad de medida del peso debe ser LB o KG (en el menú Preferencias>Ubicación)';
$_MODULE['<{fedexcarrier}prestashop>fedexcarrier_ce0c761d1e40a0da7349462787c91ac7'] = 'La unidad de medida de las dimensiones debe ser CM o IN (en el menú Preferencias>Ubicación';
$_MODULE['<{fedexcarrier}prestashop>fedexcarrier_9b8c4a7116e8c44e4ebc955fafd47586'] = 'No se ha especificado su cuenta Fedex';
$_MODULE['<{fedexcarrier}prestashop>fedexcarrier_b9cc1a101547b3ece6d946dbbe3469d7'] = 'No se ha especificado su Fedex meter Lumber';
$_MODULE['<{fedexcarrier}prestashop>fedexcarrier_5ce0f66588bbbbbb3ef0634e5ea7da69'] = 'No se ha especificado su contraseña Fedex';
$_MODULE['<{fedexcarrier}prestashop>fedexcarrier_7988c0adb770f0f945814c0fb2b5800b'] = 'No se ha especificado su Fedex API Key';
$_MODULE['<{fedexcarrier}prestashop>fedexcarrier_5d5ae09e7b6041d3449ef2cbfc39f560'] = 'No se ha especificado su método de entrega';
$_MODULE['<{fedexcarrier}prestashop>fedexcarrier_74fbfada3ebaeb00a8d14cd2c8857ec0'] = 'PrestaShop no ha podido conectarse a los servicios web de Fedex, compruebe su clave API';
$_MODULE['<{fedexcarrier}prestashop>fedexcarrier_fd0119c2a5fc18aa64887b5b7ab41c19'] = 'Se ha producido un error, inténtelo más tarde.';
$_MODULE['<{fedexcarrier}prestashop>fedexcarrier_c888438d14855d7d96a2724ee9c306bd'] = 'Configuración actualizada';
$_MODULE['<{fedexcarrier}prestashop>fedexcarrier_b9284bff13acffdd879ef4ac7fca5234'] = 'Configuración no actualizada';
